summaryrefslogtreecommitdiffstats
path: root/net/spdy/buffered_spdy_framer.h
diff options
context:
space:
mode:
authorakalin@chromium.org <akalin@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-02-15 17:56:57 +0000
committerakalin@chromium.org <akalin@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-02-15 17:56:57 +0000
commit4e974359395d6d9851a334eb6cdbf125d88b060e (patch)
tree9621dc36276ab4db3f7a663d6cc232afccc20378 /net/spdy/buffered_spdy_framer.h
parentef34dfb045fe305c5d8bb2d6cdb5b632b80086e3 (diff)
downloadchromium_src-4e974359395d6d9851a334eb6cdbf125d88b060e.zip
chromium_src-4e974359395d6d9851a334eb6cdbf125d88b060e.tar.gz
chromium_src-4e974359395d6d9851a334eb6cdbf125d88b060e.tar.bz2
Serious cleanup of SpdyFramer compression code:
* Move the compression logic into SerializeNameValueBlock. * Get rid of accessory methods like 'IsCompressible' and 'CompressControlFrame'. * Get us a few steps closer to removing SpdyControlFrame. * Add some logic to SpdyFrameBuilder to be able to build test frames more easily. * Remove need for 'compressed' argument in CreateSynStream, CreateSynReply and CreateHeaders. The argument has been left in with a DCHECK ensuring correct behavior in order to illustrate that zero behavioral change has been made. It will be removed in a follow-up CL. * Lots of other cleanup. Zero change to on-the-wire results and behavior. This lands server change 42232412. Also replaces OnControlFrameCompressed with OnSynStreamCompressed. Also maintains Chrome-specific behavior, like USE_SYSTEM_ZLIB switching and the CRIME fixes in r151720. Also pass through enable_compression_ flag in SpdySession. BUG=139744 Review URL: https://codereview.chromium.org/12263029 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@182753 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/spdy/buffered_spdy_framer.h')
-rw-r--r--net/spdy/buffered_spdy_framer.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/net/spdy/buffered_spdy_framer.h b/net/spdy/buffered_spdy_framer.h
index 512df8d..1e1fa83 100644
--- a/net/spdy/buffered_spdy_framer.h
+++ b/net/spdy/buffered_spdy_framer.h
@@ -79,9 +79,9 @@ class NET_EXPORT_PRIVATE BufferedSpdyFramerVisitorInterface {
// Called after a control frame has been compressed to allow the visitor
// to record compression statistics.
- virtual void OnControlFrameCompressed(
- const SpdyControlFrame& uncompressed_frame,
- const SpdyControlFrame& compressed_frame) = 0;
+ virtual void OnSynStreamCompressed(
+ size_t uncompressed_size,
+ size_t compressed_size) = 0;
protected:
virtual ~BufferedSpdyFramerVisitorInterface() {}
@@ -133,11 +133,11 @@ class NET_EXPORT_PRIVATE BufferedSpdyFramer
int delta_window_size) OVERRIDE;
virtual void OnDataFrameHeader(const SpdyDataFrame* frame) OVERRIDE;
- // Called after a control frame has been compressed to allow the visitor
- // to record compression statistics.
- virtual void OnControlFrameCompressed(
- const SpdyControlFrame& uncompressed_frame,
- const SpdyControlFrame& compressed_frame) OVERRIDE;
+ // Called after a syn stream control frame has been compressed to
+ // allow the visitor to record compression statistics.
+ virtual void OnSynStreamCompressed(
+ size_t uncompressed_size,
+ size_t compressed_size) OVERRIDE;
// SpdyFramer methods.
size_t ProcessInput(const char* data, size_t len);